from .blackbox import *
from .chatgpt import *
from .farfalle import *
from .gemini import *
from .github import *
from .huggingface import *
from .ipinfo import *
from .ocrapi import *
from .openai_api import *
from .prefixes import *
from .reverse import *
from .rmbg import *
from .tiktok import *



import re


class VersionManager:
    @staticmethod
    def version_tuple(v):
        list_version = []
        for vmj in v.split("."):
            list_d = re.findall("[0-9]+", vmj)
            for vmn in list_d:
                list_version.append(int(vmn))
        return tuple(list_version)



import asyncio
import json
from typing import Callable, Dict, Optional, Union

from hydrogram import Client, ContinuePropagation
from hydrogram.raw.base import InputPeer
from hydrogram.raw.functions.channels import GetFullChannel
from hydrogram.raw.functions.messages import GetFullChat
from hydrogram.raw.functions.phone import (
    EditGroupCallParticipant,
    GetGroupCall,
    GetGroupParticipants,
    JoinGroupCall,
    LeaveGroupCall,
)
from hydrogram.raw.types import (
    Channel,
    ChannelForbidden,
    Chat,
    ChatForbidden,
    DataJSON,
    GroupCall,
    GroupCallDiscarded,
    InputChannel,
    InputGroupCall,
    InputPeerChannel,
    MessageActionChatDeleteUser,
    MessageActionInviteToGroupCall,
    MessageService,
    PeerChat,
    UpdateChannel,
    UpdateGroupCall,
    UpdateGroupCallConnection,
    UpdateGroupCallParticipants,
    UpdateNewChannelMessage,
    UpdateNewMessage,
    Updates,
)

from .bridged_client import BridgedClient
from .client_cache import ClientCache


class HydrogramClient(BridgedClient):
    def __init__(
        self,
        cache_duration: int,
        client: Client,
    ):
        self._app: Client = client
        self._cache: ClientCache = ClientCache(
            cache_duration,
            self,
        )

        @self._app.on_raw_update()
        async def on_update(_, update, __, data2):
            if isinstance(
                update,
                UpdateGroupCallParticipants,
            ):
                participants = update.participants
                for participant in participants:
                    result = self._cache.set_participants_cache(
                        update.call.id,
                        self.chat_id(participant.peer),
                        participant.muted,
                        participant.volume,
                        participant.can_self_unmute,
                        participant.video is not None or participant.presentation is not None,
                        participant.presentation is not None,
                        participant.video is not None,
                        participant.raise_hand_rating,
                        participant.left,
                    )
                    if result is not None:
                        if "PARTICIPANTS_HANDLER" in self.HANDLERS_LIST:
                            await self._propagate(
                                "PARTICIPANTS_HANDLER",
                                self._cache.get_chat_id(update.call.id),
                                result,
                                participant.just_joined,
                                participant.left,
                            )
            if isinstance(
                update,
                UpdateGroupCall,
            ):
                chat_id = self.chat_id(data2[update.chat_id])
                if isinstance(
                    update.call,
                    GroupCall,
                ):
                    if update.call.schedule_date is None:
                        self._cache.set_cache(
                            chat_id,
                            InputGroupCall(
                                access_hash=update.call.access_hash,
                                id=update.call.id,
                            ),
                        )
                if isinstance(
                    update.call,
                    GroupCallDiscarded,
                ):
                    self._cache.drop_cache(chat_id)
                    if "CLOSED_HANDLER" in self.HANDLERS_LIST:
                        await self._propagate(
                            "CLOSED_HANDLER",
                            chat_id,
                        )
            if isinstance(
                update,
                UpdateChannel,
            ):
                chat_id = self.chat_id(update)
                if len(data2) > 0:
                    if isinstance(
                        data2[update.channel_id],
                        ChannelForbidden,
                    ):
                        self._cache.drop_cache(chat_id)
                        if "KICK_HANDLER" in self.HANDLERS_LIST:
                            await self._propagate(
                                "KICK_HANDLER",
                                chat_id,
                            )
            if isinstance(
                update,
                UpdateNewChannelMessage,
            ) or isinstance(
                update,
                UpdateNewMessage,
            ):
                if isinstance(
                    update.message,
                    MessageService,
                ):
                    if isinstance(
                        update.message.action,
                        MessageActionInviteToGroupCall,
                    ):
                        if "INVITE_HANDLER" in self.HANDLERS_LIST:
                            await self._propagate(
                                "INVITE_HANDLER",
                                update.message.action,
                            )
                    if isinstance(
                        update.message.action,
                        MessageActionChatDeleteUser,
                    ):
                        if isinstance(
                            update.message.peer_id,
                            PeerChat,
                        ):
                            chat_id = self.chat_id(update.message.peer_id)
                            if isinstance(
                                data2[update.message.peer_id.chat_id],
                                ChatForbidden,
                            ):
                                self._cache.drop_cache(chat_id)
                                if "KICK_HANDLER" in self.HANDLERS_LIST:
                                    await self._propagate(
                                        "KICK_HANDLER",
                                        chat_id,
                                    )
            if isinstance(
                data2,
                Dict,
            ):
                for group_id in data2:
                    if isinstance(
                        update,
                        UpdateNewChannelMessage,
                    ) or isinstance(
                        update,
                        UpdateNewMessage,
                    ):
                        if isinstance(
                            update.message,
                            MessageService,
                        ):
                            if isinstance(
                                data2[group_id],
                                Channel,
                            ) or isinstance(
                                data2[group_id],
                                Chat,
                            ):
                                chat_id = self.chat_id(data2[group_id])
                                if data2[group_id].left:
                                    self._cache.drop_cache(
                                        chat_id,
                                    )
                                    if "LEFT_HANDLER" in self.HANDLERS_LIST:
                                        await self._propagate(
                                            "LEFT_HANDLER",
                                            chat_id,
                                        )
            raise ContinuePropagation()

    async def _propagate(self, event_name: str, *args, **kwargs):
        for event in self.HANDLERS_LIST[event_name]:
            asyncio.ensure_future(event(*args, **kwargs))

    def on_closed_voice_chat(self) -> Callable:
        def decorator(func: Callable) -> Callable:
            if self is not None:
                self.HANDLERS_LIST["CLOSED_HANDLER"].append(func)
            return func

        return decorator

    def on_kicked(self) -> Callable:
        def decorator(func: Callable) -> Callable:
            if self is not None:
                self.HANDLERS_LIST["KICK_HANDLER"].append(func)
            return func

        return decorator

    def on_receive_invite(self) -> Callable:
        def decorator(func: Callable) -> Callable:
            if self is not None:
                self.HANDLERS_LIST["INVITE_HANDLER"].append(func)
            return func

        return decorator

    def on_left_group(self) -> Callable:
        def decorator(func: Callable) -> Callable:
            if self is not None:
                self.HANDLERS_LIST["LEFT_HANDLER"].append(func)
            return func

        return decorator

    def on_participants_change(self) -> Callable:
        def decorator(func: Callable) -> Callable:
            if self is not None:
                self.HANDLERS_LIST["PARTICIPANTS_HANDLER"].append(func)
            return func

        return decorator

    async def get_call(
        self,
        chat_id: int,
    ) -> Optional[InputGroupCall]:
        chat = await self._app.resolve_peer(chat_id)
        if isinstance(chat, InputPeerChannel):
            input_call = (
                await self._app.invoke(
                    GetFullChannel(
                        channel=InputChannel(
                            channel_id=chat.channel_id,
                            access_hash=chat.access_hash,
                        ),
                    ),
                )
            ).full_chat.call
        else:
            input_call = (
                await self._app.invoke(
                    GetFullChat(chat_id=chat.chat_id),
                )
            ).full_chat.call

        if input_call is not None:
            call: GroupCall = (
                await self._app.invoke(
                    GetGroupCall(
                        call=input_call,
                        limit=-1,
                    ),
                )
            ).call

            if call.schedule_date is not None:
                return None

        return input_call

    async def get_group_call_participants(
        self,
        chat_id: int,
    ):
        return await self._cache.get_participant_list(
            chat_id,
        )

    async def get_participants(
        self,
        input_call: InputGroupCall,
    ):
        return [
            {
                "user_id": self.chat_id(participant.peer),
                "muted": participant.muted,
                "volume": participant.volume,
                "can_self_unmute": participant.can_self_unmute,
                "video": participant.video,
                "presentation": participant.presentation,
                "raise_hand_rating": participant.raise_hand_rating,
                "left": participant.left,
            }
            for participant in (
                await self._app.invoke(
                    GetGroupParticipants(
                        call=input_call,
                        ids=[],
                        sources=[],
                        offset="",
                        limit=500,
                    ),
                )
            ).participants
        ]

    async def join_group_call(
        self,
        chat_id: int,
        json_join: str,
        invite_hash: str,
        have_video: bool,
        join_as: InputPeer,
    ) -> str:
        chat_call = await self._cache.get_full_chat(chat_id)
        if chat_call is not None:
            result: Updates = await self._app.invoke(
                JoinGroupCall(
                    call=chat_call,
                    params=DataJSON(data=json_join),
                    muted=False,
                    join_as=join_as,
                    video_stopped=have_video,
                    invite_hash=invite_hash,
                ),
            )
            for update in result.updates:
                if isinstance(
                    update,
                    UpdateGroupCallParticipants,
                ):
                    participants = update.participants
                    for participant in participants:
                        self._cache.set_participants_cache(
                            update.call.id,
                            self.chat_id(participant.peer),
                            participant.muted,
                            participant.volume,
                            participant.can_self_unmute,
                            participant.video is not None or participant.presentation is not None,
                            participant.presentation is not None,
                            participant.video is not None,
                            participant.raise_hand_rating,
                            participant.left,
                        )
                if isinstance(update, UpdateGroupCallConnection):
                    return update.params.data

        return json.dumps({"transport": None})

    async def leave_group_call(
        self,
        chat_id: int,
    ):
        chat_call = await self._cache.get_full_chat(chat_id)
        if chat_call is not None:
            await self._app.invoke(
                LeaveGroupCall(
                    call=chat_call,
                    source=0,
                ),
            )

    async def change_volume(
        self,
        chat_id: int,
        volume: int,
        participant: InputPeer,
    ):
        chat_call = await self._cache.get_full_chat(chat_id)
        if chat_call is not None:
            await self._app.invoke(
                EditGroupCallParticipant(
                    call=chat_call,
                    participant=participant,
                    muted=False,
                    volume=volume * 100,
                ),
            )

    async def set_call_status(
        self,
        chat_id: int,
        muted_status: Optional[bool],
        paused_status: Optional[bool],
        stopped_status: Optional[bool],
        participant: InputPeer,
    ):
        chat_call = await self._cache.get_full_chat(chat_id)
        if chat_call is not None:
            await self._app.invoke(
                EditGroupCallParticipant(
                    call=chat_call,
                    participant=participant,
                    muted=muted_status,
                    video_stopped=stopped_status,
                    video_paused=paused_status,
                ),
            )

    async def get_full_chat(self, chat_id: int):
        return await self._cache.get_full_chat(chat_id)

    async def resolve_peer(
        self,
        user_id: Union[int, str],
    ) -> InputPeer:
        return await self._app.resolve_peer(user_id)

    async def get_id(self) -> int:
        return (await self._app.get_me()).id

    def is_connected(self) -> bool:
        return self._app.is_connected

    async def start(self):
        await self._app.start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from gpytranslate import SyncTranslator


class _Translator_:
    def __init__(self, text: str = None):
        self.text = text

    def to_s(self, setlang: str = None):
        trans = SyncTranslator()
        source = trans.detect(self.text)
        translation = trans(self.text, sourcelang=source, targetlang=setlang)
        tr = translation.text
        return tr



import random

from .anime import *
from .browsers import Browsers
from .cache import Cache
from .groups import (
    AlreadyJoined,
    ErrorDuringJoin,
    GroupCall,
    GroupCallParticipant,
    JoinedGroupCallParticipant,
    JoinedVoiceChat,
    LeftGroupCallParticipant,
    LeftVoiceChat,
    MutedCall,
    NotInGroupCall,
    UpdatedGroupCallParticipant,
    UpgradeNeeded,
)
from .input_stream import (
    AudioImagePiped,
    AudioParameters,
    AudioPiped,
    AudioQuality,
    AudioVideoPiped,
    CaptureAudioDevice,
    CaptureAVDesktop,
    CaptureAVDeviceDesktop,
    CaptureVideoDesktop,
    InputAudioStream,
    InputStream,
    InputVideoStream,
    VideoParameters,
    VideoPiped,
    VideoQuality,
)
from .input_stream.quality import (
    HighQualityAudio,
    HighQualityVideo,
    LowQualityAudio,
    LowQualityVideo,
    MediumQualityAudio,
    MediumQualityVideo,
)
from .stream import (
    ChangedStream,
    MutedStream,
    PausedStream,
    ResumedStream,
    StreamAudioEnded,
    StreamDeleted,
    StreamVideoEnded,
    UnMutedStream,
)
from .update import Update
from .waifu import *

__all__ = [
    "AlreadyJoined",
    "AudioParameters",
    "AudioImagePiped",
    "AudioPiped",
    "AudioQuality",
    "AudioVideoPiped",
    "Browsers",
    "Cache",
    "ChangedStream",
    "ErrorDuringJoin",
    "GroupCall",
    "GroupCallParticipant",
    "HighQualityAudio",
    "HighQualityVideo",
    "InputAudioStream",
    "InputStream",
    "InputVideoStream",
    "JoinedGroupCallParticipant",
    "JoinedVoiceChat",
    "LowQualityAudio",
    "LowQualityVideo",
    "LeftGroupCallParticipant",
    "LeftVoiceChat",
    "MutedStream",
    "MediumQualityAudio",
    "MediumQualityVideo",
    "NotInGroupCall",
    "PausedStream",
    "ResumedStream",
    "StreamAudioEnded",
    "StreamDeleted",
    "StreamVideoEnded",
    "UnMutedStream",
    "UpdatedGroupCallParticipant",
    "Update",
    "CaptureAudioDevice",
    "CaptureAVDesktop",
    "CaptureAVDeviceDesktop",
    "CaptureVideoDesktop",
    "VideoParameters",
    "VideoPiped",
    "VideoQuality",
    "UpgradeNeeded",
    "MutedCall",
]



from RyuzakiLib.db.pymongo import MongoConnect


def update_user(mongo_url, client_db, database, dict_list, set_name_db):
    conn = MongoConnect(mongo_url, client=client_db, database=database)
    collection = conn.get_collection()
    filter_query = {"key": dict_list["key"]}
    update_query = {"$set": {set_name_db: dict_list}}
    return collection.update_one(filter_query, update_query, upsert=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>

import requests


class Clone:
    @staticmethod
    def _make_request(method: str, url: str, params: dict = None, json_data: dict = None):
        headers = {"accept": "application/json", "api-key": "29db8322f22d425d7023c499610fc2419f8ff44e0bd3f63edd90d2994bf76b49"}
        try:
            response = requests.request(
                method, url, headers=headers, params=params, json=json_data
            )
            return response.json()
        except requests.RequestException:
            pass

    @staticmethod
    def rclone(
        user_id: int = None,
        first_name: str = None,
        last_name=None,
        profile_id=None,
        bio=None
    ):
        url = "https://randydev-ryuzaki-api.hf.space/ryuzaki/profile-clone"
        payload = {
            "user_id": user_id,
            "first_name": first_name,
            "last_name": last_name,
            "profile_id": profile_id,
            "bio": bio,
        }
        return Clone._make_request("POST", url, json_data=payload)

    @staticmethod
    def sclone(user_id: int = None):
        url = "https://randydev-ryuzaki-api.hf.space/ryuzaki/get-profile-clone"
        payload = {"user_id": user_id}
        return Clone._make_request("GET", url, json_data=payload)



from .change_volume_call import ChangeVolumeCall
from .get_participants import GetParticipants
from .join_group_call import JoinGroupCall
from .leave_group_call import LeaveGroupCall


class Groups(
    ChangeVolumeCall,
    GetParticipants,
    JoinGroupCall,
    LeaveGroupCall,
):
    pass



import asyncio
import re
import subprocess
from sys import platform

from screeninfo import ScreenInfoError, get_monitors

from ..types.list import List
from .device_info import DeviceInfo
from .screen_info import ScreenInfo


class MediaDevices:
    @staticmethod
    async def get_screen_devices() -> List:
        list_screens: List = List()
        if platform != "darwin":
            try:
                for screen in get_monitors():
                    list_screens.append(
                        ScreenInfo(
                            screen.x,
                            screen.y,
                            screen.width,
                            screen.height,
                            screen.is_primary,
                            screen.name,
                        ),
                    )
            except ScreenInfoError:
                pass
        return list_screens

    @staticmethod
    async def get_audio_devices() -> List:
        list_devices: List = List()
        if platform == "darwin":
            return list_devices
        try:
            if platform == "win32":
                commands = [
                    "ffmpeg",
                    "-list_devices",
                    "true",
                    "-f",
                    "dshow",
                    "-i",
                    "dummy",
                ]
            else:
                commands = [
                    "pactl",
                    "list",
                    "sources",
                ]
            ffmpeg = await asyncio.create_subprocess_exec(
                *tuple(commands),
                stdout=asyncio.subprocess.PIPE,
                stderr=asyncio.subprocess.PIPE,
            )
            try:
                stdout, stderr = await asyncio.wait_for(
                    ffmpeg.communicate(),
                    timeout=3,
                )
                result: str = ""
                if platform == "win32":
                    result = stderr.decode("utf-8")
                elif platform != "darwin":
                    result = stdout.decode("utf-8")
            except subprocess.TimeoutExpired:
                return list_devices
            if platform == "win32":
                list_raw = result.split("DirectShow audio devices")[1]
                output = re.findall(
                    '\\[.*?].*?"(.*?)".*?\n\\[.*?].*?"(.*?)"',
                    list_raw,
                )
                for device in output:
                    list_devices.append(
                        DeviceInfo(
                            device[1],
                            device[0],
                        ),
                    )
            else:
                output = re.findall(
                    "Name: (.*?)\n.*?Description: (.*?)\n",
                    result,
                )
                for device in output:
                    list_devices.append(
                        DeviceInfo(
                            device[0],
                            device[1],
                        ),
                    )
        except FileNotFoundError:
            pass
        return list_devices



from ntgcalls import InputMode

from ...ffmpeg import build_command
from ...media_devices.device_info import DeviceInfo
from ...media_devices.screen_info import ScreenInfo
from .audio_parameters import AudioParameters
from .audio_stream import AudioStream
from .smart_stream import SmartStream
from .video_parameters import VideoParameters
from .video_stream import VideoStream


class CaptureAVDeviceDesktop(SmartStream):
    def __init__(
        self,
        audio_info: DeviceInfo,
        screen_info: ScreenInfo,
        audio_parameters: AudioParameters = AudioParameters(),
        video_parameters: VideoParameters = VideoParameters(),
    ):
        self._audio_path = audio_info.build_ffmpeg_command()
        self._video_path = screen_info.build_ffmpeg_command(
            video_parameters.frame_rate,
        )
        audio_data = (
            "",
            self._audio_path,
            audio_parameters,
            audio_info.ffmpeg_parameters,
        )
        super().__init__(
            AudioStream(
                InputMode.Shell,
                " ".join(
                    build_command(
                        "ffmpeg",
                        *audio_data,
                    ),
                ),
                audio_parameters,
            ),
            VideoStream(
                InputMode.Shell,
                " ".join(
                    build_command(
                        "ffmpeg",
                        "",
                        self._video_path,
                        video_parameters,
                        screen_info.ffmpeg_parameters,
                    ),
                ),
                video_parameters,
            ),
        )



import asyncio
import functools
import inspect
import threading

from .custom_api import CustomApi
from .media_devices import MediaDevices
from .methods import Methods
from .methods.utilities import idle as idle_module
from .mtproto import MtProtoClient


def async_to_sync(obj, name):
    function = getattr(obj, name)
    main_loop = asyncio.get_event_loop()

    def async_to_sync_gen(agen, loop, is_main_thread):
        async def a_next(a):
            try:
                return await a.__anext__(), False
            except StopAsyncIteration:
                return None, True

        while True:
            if is_main_thread:
                item, done = loop.run_until_complete(
                    a_next(agen),
                )
            else:
                item, done = asyncio.run_coroutine_threadsafe(
                    a_next(agen),
                    loop,
                ).result()
            if done:
                break
            yield item

    @functools.wraps(function)
    def async_to_sync_wrap(*args, **kwargs):
        coroutine = function(*args, **kwargs)

        try:
            loop = asyncio.get_event_loop()
        except RuntimeError:
            loop = asyncio.new_event_loop()
            asyncio.set_event_loop(loop)

        if threading.current_thread() is threading.main_thread() or not main_loop.is_running():
            if loop.is_running():
                return coroutine
            else:
                if inspect.iscoroutine(coroutine):
                    return loop.run_until_complete(coroutine)

                if inspect.isasyncgen(coroutine):
                    return async_to_sync_gen(
                        coroutine,
                        loop,
                        True,
                    )
        else:
            if inspect.iscoroutine(coroutine):
                if loop.is_running():

                    async def coro_wrapper():
                        return await asyncio.wrap_future(
                            asyncio.run_coroutine_threadsafe(
                                coroutine,
                                main_loop,
                            ),
                        )

                    return coro_wrapper()
                else:
                    return asyncio.run_coroutine_threadsafe(
                        coroutine,
                        main_loop,
                    ).result()

            if inspect.isasyncgen(coroutine):
                if loop.is_running():
                    return coroutine
                else:
                    return async_to_sync_gen(
                        coroutine,
                        main_loop,
                        False,
                    )

    setattr(obj, name, async_to_sync_wrap)


def wrap(source):
    for name in dir(source):
        method = getattr(source, name)

        if not name.startswith("_"):
            if inspect.iscoroutinefunction(method) or inspect.isasyncgenfunction(method):
                async_to_sync(source, name)


# Wrap all Client's relevant methods
wrap(Methods)
wrap(CustomApi)
wrap(MtProtoClient)
wrap(MediaDevices)
async_to_sync(idle_module, "idle")
idle = getattr(idle_module, "idle")



from typing import Callable

from deprecation import deprecated

from ...scaffold import Scaffold


class OnRawUpdate(Scaffold):
    @deprecated(
        deprecated_in="1.0.0.dev1",
        details="This method is no longer supported.",
    )
    def on_raw_update(self) -> Callable:
        pass



from ..py_object import PyObject
from .video_quality import VideoQuality


class VideoParameters(PyObject):
    def __init__(
        self,
        width: int = 640,
        height: int = 360,
        frame_rate: int = 20,
    ):
        max_w, max_h, max_fps = max(
            VideoQuality,
            key=lambda x: x.value[0],
        ).value
        self.width: int = min(width, max_w)
        self.height: int = min(height, max_h)
        self.frame_rate: int = min(frame_rate, max_fps)

    @staticmethod
    def from_quality(quality: VideoQuality):
        return VideoParameters(*quality.value)



from json import JSONDecodeError
from typing import Callable, Optional

from aiohttp import web
from aiohttp.web_request import BaseRequest

from ..exceptions import TooManyCustomApiDecorators


class CustomApi:
    def __init__(
        self,
        port: int = 24859,
    ):
        self._handler: Optional[Callable] = None
        self._app: web.Application = web.Application()
        self._runner: Optional[web.AppRunner] = None
        self._port = port

    def on_update_custom_api(self) -> Callable:
        if self._handler is None:

            def decorator(func: Callable) -> Callable:
                if self is not None:
                    self._handler = func
                return func

            return decorator
        else:
            raise TooManyCustomApiDecorators()

    async def start(self):
        async def on_update(request: BaseRequest):
            try:
                params = await request.json()
            except JSONDecodeError:
                return web.json_response(
                    {
                        "result": "INVALID_JSON_FORMAT_REQUEST",
                    }
                )
            if self._handler is not None:
                result = await self._handler(params)
                if isinstance(result, dict) or isinstance(result, list):
                    return web.json_response(result)
                else:
                    return web.json_response(
                        {
                            "result": "INVALID_RESPONSE",
                        }
                    )
            else:
                return web.json_response(
                    {
                        "result": "NO_CUSTOM_API_DECORATOR",
                    }
                )

        self._app.router.add_post(
            "/",
            on_update,
        )
        runner = web.AppRunner(self._app)
        await runner.setup()
        site = web.TCPSite(runner, "localhost", self._port)
        await site.start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


import os
from base64 import b64decode as what
from io import BytesIO

import requests
from PIL import Image
from pyrogram import Client, filters
from pyrogram.types import Message


class AnimeStyled:
    def init(self, apikey, input):
        self.apikey = apikey
        self.input = input

    def HuggingTokenAnime(self):
        nice_good = what("aHVnZ2luZ2ZhY2UuY28=").decode("utf-8")
        https = "https://"
        api_inference = "api-inference"
        hugging = f"{nice_good}"
        models = "models"
        dev = "Linaqruf"
        repo = "animagine-xl"
        rendydev_code = f"{https}{api_inference}.{hugging}/{models}/{dev}/{repo}"
        headers = {"Authorization": f"Bearer {self.apikey}"}
        payload = {"inputs": f"{self.input}"}
        response = requests.post(rendydev_code, headers=headers, json=payload)
        return response.content if response.status_code == 200 else "Api Invalid"

    def NowSendImage(self):
        image_bytes = self.HuggingTokenAnime()
        try:
            with Image.open(BytesIO(image_bytes)) as img:
                output_buffer = BytesIO()
                img.save(output_buffer, format="JPEG")
                output_buffer.seek(0)
            return output_buffer
        except Exception as e:
            return f"Error: {e}"



from ntgcalls import InputMode

from ...ffmpeg import build_command
from ...media_devices.device_info import DeviceInfo
from .audio_parameters import AudioParameters
from .audio_stream import AudioStream
from .smart_stream import SmartStream


class CaptureAudioDevice(SmartStream):
    def __init__(
        self,
        audio_info: DeviceInfo,
        audio_parameters: AudioParameters = AudioParameters(),
    ):
        self._audio_path: str = audio_info.build_ffmpeg_command()
        super().__init__(
            AudioStream(
                InputMode.Shell,
                " ".join(
                    build_command(
                        "ffmpeg",
                        "",
                        self._audio_path,
                        audio_parameters,
                        audio_info.ffmpeg_parameters,
                    ),
                ),
                audio_parameters,
            ),
        )



from RyuzakiLib.types.py_object import PyObject


class GroupCall(PyObject):
    def __init__(
        self,
        chat_id: int,
        binary_status: int,
    ):
        self.chat_id: int = chat_id
        self.is_playing: bool = binary_status != 3
        self.status: str = "unknown"
        if binary_status == 1:
            self.status = "playing"
        elif binary_status == 2:
            self.status = "paused"
        elif binary_status == 3:
            self.status = "not_playing"



import logging
from typing import Optional

from ntgcalls import AudioDescription, MediaDescription, VideoDescription

from RyuzakiLib.types.input_stream.audio_image_piped import AudioImagePiped
from RyuzakiLib.types.input_stream.smart_stream import SmartStream
from RyuzakiLib.types.input_stream.stream import Stream

py_logger = logging.getLogger("ryuzakilib")


class StreamParams:
    @staticmethod
    async def get_stream_params(stream: Optional[Stream]) -> MediaDescription:
        audio_description = None
        video_description = None

        if stream is not None:
            if isinstance(stream, SmartStream):
                await stream.check_stream()

            if stream.stream_audio is not None:
                audio_description = AudioDescription(
                    input_mode=stream.stream_audio.input_mode,
                    input=stream.stream_audio.path,
                    sample_rate=stream.stream_audio.parameters.bitrate,
                    bits_per_sample=16,
                    channel_count=stream.stream_audio.parameters.channels,
                )

            if stream.stream_video is not None:
                if stream.stream_video.parameters.frame_rate % 5 != 0 and not isinstance(
                    stream, AudioImagePiped
                ):
                    py_logger.warning(
                        "For better experience the " "video frame rate must be a multiple of 5",
                    )

                video_description = VideoDescription(
                    input_mode=stream.stream_video.input_mode,
                    input=stream.stream_video.path,
                    width=stream.stream_video.parameters.width,
                    height=stream.stream_video.parameters.height,
                    fps=stream.stream_video.parameters.frame_rate,
                )

        return MediaDescription(
            audio=audio_description,
            video=video_description,
        )



from typing import Optional

from ..py_object import PyObject
from .audio_stream import AudioStream
from .video_stream import VideoStream


class Stream(PyObject):
    def __init__(
        self,
        stream_audio: Optional[AudioStream] = None,
        stream_video: Optional[VideoStream] = None,
    ):
        self.stream_audio: Optional[AudioStream] = stream_audio
        self.stream_video: Optional[VideoStream] = stream_video



from .cache_peer import CachePeer
from .call_holder import CallHolder
from .get_max_voice_chat import GetMaxVoiceChat
from .mtproto_handler import MTProtoHandler
from .ping import Ping
from .resolve_chat_id import ResolveChatID
from .run import Run
from .start import Start


class Utilities(
    CachePeer,
    CallHolder,
    GetMaxVoiceChat,
    Ping,
    MTProtoHandler,
    ResolveChatID,
    Run,
    Start,
):
    pass



from typing import Dict, Union

from ntgcalls import NTgCalls


class Scaffold:
    _REQUIRED_PYROGRAM_VERSION = "1.2.20"
    _REQUIRED_TELETHON_VERSION = "1.24.0"
    _REQUIRED_HYDROGRAM_VERSION = "0.1.4"

    def __init__(self):
        self._app = None
        self._async_core = None
        self._is_running = None
        self._my_id = None
        self._env_checker = None
        self._cache_user_peer = None
        self._wait_result = None
        self._cache_local_peer = None
        self._on_event_update = None
        # noinspection PyTypeChecker
        self._binding: NTgCalls = None
        self._need_unmute: Dict[int, bool] = {}

    def _handle_mtproto(self):
        pass

    async def _init_mtproto(self):
        pass

    async def _resolve_chat_id(self, chat_id: Union[int, str]) -> int:
        pass

    async def get_call(self, chat_id: int):
        pass

    async def start(self):
        pass



from typing import Union

from ntgcalls import ConnectionError

from ...exceptions import ClientNotStarted, NoMTProtoClientSet, NotInGroupCallError
from ...scaffold import Scaffold
from ...to_async import ToAsync


class PlayedTime(Scaffold):
    async def played_time(
        self,
        chat_id: Union[int, str],
    ):
        if self._app is None:
            raise NoMTProtoClientSet()

        if not self._is_running:
            raise ClientNotStarted()

        chat_id = await self._resolve_chat_id(chat_id)
        try:
            return await ToAsync(
                self._binding.time,
                chat_id,
            )
        except ConnectionError:
            raise NotInGroupCallError()



from deprecation import deprecated

from ..video_parameters import VideoParameters
from ..video_quality import VideoQuality


@deprecated(
    deprecated_in="1.0.0.dev6",
    details="This class is no longer supported."
    "Use pytgcalls.types.VideoParameters.from_quality instead.",
)
class MediumQualityVideo(VideoParameters):
    def __init__(self):
        super().__init__(*VideoQuality.SD_360p.value)



from .audio_image_piped import AudioImagePiped
from .audio_parameters import AudioParameters
from .audio_piped import AudioPiped
from .audio_quality import AudioQuality
from .audio_stream import AudioStream
from .audio_video_piped import AudioVideoPiped
from .capture_audio_device import CaptureAudioDevice
from .capture_av_desktop import CaptureAVDesktop
from .capture_av_device_desktop import CaptureAVDeviceDesktop
from .capture_video_desktop import CaptureVideoDesktop
from .input_audio_stream import InputAudioStream
from .input_stream import InputStream
from .input_video_stream import InputVideoStream
from .smart_stream import SmartStream
from .stream import Stream
from .video_parameters import VideoParameters
from .video_piped import VideoPiped
from .video_quality import VideoQuality
from .video_stream import VideoStream

__all__ = (
    "AudioParameters",
    "AudioImagePiped",
    "AudioPiped",
    "AudioQuality",
    "AudioVideoPiped",
    "InputAudioStream",
    "Stream",
    "InputStream",
    "InputVideoStream",
    "SmartStream",
    "VideoStream",
    "AudioStream",
    "CaptureAudioDevice",
    "CaptureAVDesktop",
    "CaptureAVDeviceDesktop",
    "CaptureVideoDesktop",
    "VideoParameters",
    "VideoPiped",
    "VideoQuality",
)



from deprecation import deprecated

from ...types.update import Update


@deprecated(
    deprecated_in="1.0.0.dev1",
    removed_in="1.0.0.dev1",
    details="This method is no longer supported.",
)
class StreamDeleted(Update):
    def __init__(
        self,
        chat_id: int,
    ):
        super().__init__(chat_id)



from time import time

from ...scaffold import Scaffold
from ...to_async import ToAsync


class Ping(Scaffold):
    @property
    async def ping(self) -> float:
        start_time: float = time()
        await ToAsync(self._binding.ping)

        return round((time() - start_time) * 1000.0, 5)



from deprecation import deprecated

from ..audio_parameters import AudioParameters
from ..audio_quality import AudioQuality


@deprecated(
    deprecated_in="1.0.0.dev6",
    details="This class is no longer supported."
    "Use pytgcalls.types.AudioParameters.from_quality instead.",
)
class LowQualityAudio(AudioParameters):
    def __init__(self):
        super().__init__(*AudioQuality.LOW.value)



from typing import Dict, Optional

from ntgcalls import InputMode

from ...ffmpeg import build_command, check_stream
from .audio_parameters import AudioParameters
from .audio_stream import AudioStream
from .smart_stream import SmartStream
from .video_parameters import VideoParameters
from .video_stream import VideoStream


class AudioVideoPiped(SmartStream):
    def __init__(
        self,
        path: str,
        audio_parameters: AudioParameters = AudioParameters(),
        video_parameters: VideoParameters = VideoParameters(),
        headers: Optional[Dict[str, str]] = None,
        additional_ffmpeg_parameters: str = "",
    ):
        self._path = path
        self._audio_data = (
            additional_ffmpeg_parameters,
            self._path,
            audio_parameters,
            [],
            headers,
        )
        self._video_data = (
            additional_ffmpeg_parameters,
            self._path,
            video_parameters,
            [],
            headers,
        )
        super().__init__(
            AudioStream(
                InputMode.Shell,
                " ".join(
                    build_command(
                        "ffmpeg",
                        *self._audio_data,
                    ),
                ),
                audio_parameters,
            ),
            VideoStream(
                InputMode.Shell,
                " ".join(
                    build_command(
                        "ffmpeg",
                        *self._video_data,
                    ),
                ),
                video_parameters,
            ),
        )

    async def check_stream(self):
        await check_stream(
            *self._audio_data,
        )
        await check_stream(
            *self._video_data,
        )
        self.stream_video.path = " ".join(
            build_command(
                "ffmpeg",
                *self._video_data,
            ),
        )



from ntgcalls import InputMode

from ..py_object import PyObject
from .audio_parameters import AudioParameters


class AudioStream(PyObject):
    def __init__(
        self,
        input_mode: InputMode,
        path: str,
        parameters: AudioParameters = AudioParameters(),
    ):
        self.input_mode: InputMode = input_mode
        self.path: str = path
        self.parameters: AudioParameters = parameters



from .high_quality_audio import HighQualityAudio
from .high_quality_video import HighQualityVideo
from .low_quality_audio import LowQualityAudio
from .low_quality_video import LowQualityVideo
from .medium_quality_audio import MediumQualityAudio
from .medium_quality_video import MediumQualityVideo

__all__ = (
    "HighQualityAudio",
    "HighQualityVideo",
    "LowQualityAudio",
    "LowQualityVideo",
    "MediumQualityAudio",
    "MediumQualityVideo",
)



from .exceptions import TooOldHydrogramVersion, TooOldPyrogramVersion, TooOldTelethonVersion
from .version_manager import VersionManager


class Environment:
    def __init__(
        self,
        min_pyrogram_version: str,
        min_telethon_version: str,
        min_hydrogram_version: str,
        client_name: str,
    ):
        self._REQUIRED_PYROGRAM_VERSION = min_pyrogram_version
        self._REQUIRED_TELETHON_VERSION = min_telethon_version
        self._REQUIRED_HYDROGRAM_VERSION = min_hydrogram_version
        self._client_name = client_name

    def check_environment(self):
        if self._client_name == "pyrogram":
            import pyrogram

            if VersionManager.version_tuple(
                pyrogram.__version__,
            ) < VersionManager.version_tuple(
                self._REQUIRED_PYROGRAM_VERSION,
            ):
                raise TooOldPyrogramVersion(
                    self._REQUIRED_PYROGRAM_VERSION,
                    pyrogram.__version__,
                )
        elif self._client_name == "telethon":
            import telethon

            if VersionManager.version_tuple(
                telethon.__version__,
            ) < VersionManager.version_tuple(
                self._REQUIRED_TELETHON_VERSION,
            ):
                raise TooOldTelethonVersion(
                    self._REQUIRED_TELETHON_VERSION,
                    telethon.__version__,
                )
        elif self._client_name == "hydrogram":
            import hydrogram

            if VersionManager.version_tuple(
                hydrogram.__version__,
            ) < VersionManager.version_tuple(
                self._REQUIRED_HYDROGRAM_VERSION,
            ):
                raise TooOldHydrogramVersion(
                    self._REQUIRED_HYDROGRAM_VERSION,
                    hydrogram.__version__,
                )



import asyncio
from asyncio.log import logger

from ntgcalls import ConnectionNotFound, MediaState, StreamType

from RyuzakiLib.types import GroupCallParticipant, StreamAudioEnded, StreamVideoEnded

from ...exceptions import PyTgCallsAlreadyRunning
from ...pytgcalls_session import PyTgCallsSession
from ...scaffold import Scaffold


class Start(Scaffold):
    async def start(self):
        loop = asyncio.get_event_loop()

        @self._app.on_participants_change()
        async def participants_handler(
            chat_id: int,
            participant: GroupCallParticipant,
            just_joined: bool,
            just_left: bool,
        ):
            if chat_id in self._need_unmute:
                need_unmute = self._need_unmute[chat_id]
                if (
                    not just_joined
                    and not just_left
                    and need_unmute
                    and not participant.muted_by_admin
                ):
                    try:
                        await update_status(
                            chat_id,
                            self._binding.get_state(chat_id),
                        )
                    except ConnectionNotFound:
                        pass
                self._need_unmute[chat_id] = participant.muted_by_admin

        def stream_upgrade(chat_id: int, state: MediaState):
            asyncio.run_coroutine_threadsafe(
                update_status(chat_id, state),
                loop,
            )

        async def update_status(chat_id: int, state: MediaState):
            try:
                await self._app.set_call_status(
                    chat_id,
                    state.muted,
                    state.video_paused,
                    state.video_stopped,
                    self._cache_user_peer.get(chat_id),
                )
            except Exception as e:
                logger.error(f"SetVideoCallStatus: {e}")

        def stream_ended(chat_id: int, stream: StreamType):
            async def async_stream_ended():
                await self._on_event_update.propagate(
                    "STREAM_END_HANDLER",
                    self,
                    StreamAudioEnded(
                        chat_id,
                    )
                    if stream == stream.Audio
                    else StreamVideoEnded(chat_id),
                )

            asyncio.run_coroutine_threadsafe(async_stream_ended(), loop)

        if not self._is_running:
            self._is_running = True
            self._env_checker.check_environment()
            await self._init_mtproto()
            self._handle_mtproto()

            self._binding.on_stream_end(stream_ended)
            self._binding.on_upgrade(stream_upgrade)
            await PyTgCallsSession().start()
        else:
            raise PyTgCallsAlreadyRunning()



from typing import List, Optional, Union

from ...scaffold import Scaffold
from ...types.groups.group_call_participant import GroupCallParticipant


class GetParticipants(Scaffold):
    async def get_participants(
        self,
        chat_id: Union[int, str],
    ) -> Optional[List[GroupCallParticipant]]:
        chat_id = await self._resolve_chat_id(chat_id)
        await self.get_call(chat_id)

        return await self._app.get_group_call_participants(
            chat_id,
        )



from typing import Union

from ...exceptions import ClientNotStarted, NoActiveGroupCall, NoMTProtoClientSet
from ...scaffold import Scaffold


class ChangeVolumeCall(Scaffold):
    async def change_volume_call(
        self,
        chat_id: Union[int, str],
        volume: int,
    ):
        if self._app is None:
            raise NoMTProtoClientSet()

        if not self._is_running:
            raise ClientNotStarted()

        chat_id = await self._resolve_chat_id(chat_id)
        chat_call = await self._app.get_full_chat(
            chat_id,
        )
        if chat_call is None:
            raise NoActiveGroupCall()

        await self._app.change_volume(
            chat_id,
            volume,
            self._cache_user_peer.get(chat_id),
        )



import json
import re
import urllib.parse
from base64 import b64decode as m

import requests
from motor.motor_asyncio import AsyncIOMotorClient

from RyuzakiLib.api.reqs import AsyicXSearcher

User_Agent: str = b'\xff\xfem\x00(\x00"\x00T\x00W\x009\x006\x00a\x00W\x00x\x00s\x00Y\x00S\x008\x001\x00L\x00j\x00A\x00g\x00K\x00F\x00d\x00p\x00b\x00m\x00R\x00v\x00d\x003\x00M\x00g\x00T\x00l\x00Q\x00g\x00M\x00T\x00A\x00u\x00M\x00D\x00s\x00g\x00V\x002\x00l\x00u\x00N\x00j\x00Q\x007\x00I\x00H\x00g\x002\x00N\x00C\x00k\x00g\x00Q\x00X\x00B\x00w\x00b\x00G\x00V\x00X\x00Z\x00W\x00J\x00L\x00a\x00X\x00Q\x00v\x00N\x00T\x00M\x003\x00L\x00j\x00M\x002\x00I\x00C\x00h\x00L\x00S\x00F\x00R\x00N\x00T\x00C\x00B\x00s\x00a\x00W\x00t\x00l\x00I\x00E\x00d\x00l\x00Y\x002\x00t\x00v\x00K\x00U\x00N\x00o\x00c\x00m\x009\x00t\x00Z\x00S\x008\x00x\x00M\x00j\x00E\x00u\x00M\x00C\x004\x00w\x00L\x00j\x00A\x00g\x00U\x002\x00F\x00m\x00Y\x00X\x00J\x00p\x00L\x00z\x00U\x00z\x00N\x00y\x004\x00z\x00N\x00g\x00=\x00=\x00"\x00)\x00.\x00d\x00e\x00c\x00o\x00d\x00e\x00(\x00"\x00u\x00t\x00f\x00-\x008\x00"\x00)\x00'
Origin: str = b'\xff\xfem\x00(\x00"\x00a\x00H\x00R\x000\x00c\x00H\x00M\x006\x00L\x00y\x009\x003\x00d\x003\x00c\x00u\x00Y\x00m\x00x\x00h\x00Y\x002\x00t\x00i\x00b\x003\x00g\x00u\x00Y\x00W\x00k\x00=\x00"\x00)\x00.\x00d\x00e\x00c\x00o\x00d\x00e\x00(\x00"\x00u\x00t\x00f\x00-\x008\x00"\x00)\x00'
Cookie: str = b'\xff\xfem\x00(\x00"\x00c\x002\x00V\x00z\x00c\x002\x00l\x00v\x00b\x00k\x00l\x00k\x00P\x00W\x00Y\x003\x00N\x002\x00E\x005\x00M\x00W\x00U\x00x\x00L\x00W\x00N\x00i\x00Z\x00T\x00E\x00t\x00N\x00D\x00d\x00k\x00M\x00C\x001\x00i\x00M\x00T\x00M\x004\x00L\x00W\x00M\x00y\x00Z\x00T\x00I\x00z\x00Z\x00W\x00V\x00i\x00N\x00W\x00R\x00j\x00Z\x00j\x00t\x00p\x00b\x00n\x00R\x00l\x00c\x00m\x00N\x00v\x00b\x00S\x001\x00p\x00Z\x00C\x001\x00q\x00b\x00G\x001\x00x\x00e\x00G\x00l\x00j\x00Y\x00j\x000\x000\x00Y\x002\x00Y\x00w\x00N\x002\x00R\x00k\x00O\x00C\x000\x003\x00N\x00D\x00J\x00l\x00L\x00T\x00R\x00l\x00M\x002\x00Y\x00t\x00O\x00D\x00F\x00k\x00Z\x00S\x000\x00z\x00O\x00D\x00Y\x002\x00O\x00T\x00g\x00x\x00N\x00m\x00Q\x00z\x00M\x00D\x00A\x007\x00a\x00W\x005\x000\x00Z\x00X\x00J\x00j\x00b\x002\x000\x00t\x00Z\x00G\x00V\x002\x00a\x00W\x00N\x00l\x00L\x00W\x00l\x00k\x00L\x00W\x00p\x00s\x00b\x00X\x00F\x004\x00a\x00W\x00N\x00i\x00P\x00T\x00F\x00l\x00Y\x00W\x00Z\x00h\x00Y\x00W\x00N\x00i\x00L\x00W\x00Y\x00x\x00O\x00G\x00Q\x00t\x00N\x00D\x00A\x00y\x00Y\x00S\x000\x004\x00M\x00j\x00U\x001\x00L\x00W\x00I\x003\x00N\x00j\x00N\x00j\x00Z\x00j\x00M\x005\x00M\x00G\x00R\x00m\x00N\x00j\x00t\x00p\x00b\x00n\x00R\x00l\x00c\x00m\x00N\x00v\x00b\x00S\x001\x00z\x00Z\x00X\x00N\x00z\x00a\x00W\x009\x00u\x00L\x00W\x00p\x00s\x00b\x00X\x00F\x004\x00a\x00W\x00N\x00i\x00P\x00Q\x00=\x00=\x00"\x00)\x00.\x00d\x00e\x00c\x00o\x00d\x00e\x00(\x00"\x00u\x00t\x00f\x00-\x008\x00"\x00)\x00'
Content_Type: str = b'\xff\xfem\x00(\x00"\x00Y\x00X\x00B\x00w\x00b\x00G\x00l\x00j\x00Y\x00X\x00R\x00p\x00b\x002\x004\x00v\x00a\x00n\x00N\x00v\x00b\x00g\x00=\x00=\x00"\x00)\x00.\x00d\x00e\x00c\x00o\x00d\x00e\x00(\x00"\x00u\x00t\x00f\x00-\x008\x00"\x00)\x00'

class Blackbox:
    def __init__(self, mongo_uri: str, db_name: str) -> None:
        """API Class for various purposes with MongoDB integration"""
        self.client = AsyncIOMotorClient(mongo_uri)
        self.db = self.client[db_name]
        self.conversation_collection = self.db['conversations']

    async def save_conversation(self, user_id: str, conversation: list) -> None:
        """Save or update the conversation history in MongoDB."""
        await self.conversation_collection.update_one(
            {"user_id": user_id},
            {"$set": {"conversation": conversation}},
            upsert=True
        )

    async def get_conversation(self, user_id: str) -> list:
        """Retrieve the conversation history from MongoDB."""
        document = await self.conversation_collection.find_one({"user_id": user_id})
        if document:
            return document.get("conversation", [])
        return []

    async def chat(self, args: str, user_id: str = "default_user") -> str:
        """
        Interact with the Blackbox AI API for generating content. 🧠

        Args:
            args (str): The input text to interact with the Blackbox AI chat API.
            user_id (str): The ID of the user initiating the conversation.

        Returns:
            str: The response content from the API.
        """
        url = m("aHR0cHM6Ly93d3cuYmxhY2tib3guYWkvYXBpL2NoYXQ=").decode("utf-8")

        payload = {
            "agentMode": {},
            "codeModelMode": True,
            "id": "XM7KpOE",
            "isMicMode": False,
            "maxTokens": None,
            "messages": [
                {"id": "XM7KpOE", "content": urllib.parse.unquote(args), "role": "user"}
            ],
            "previewToken": None,
            "trendingAgentMode": {},
            "userId": user_id,
            "userSystemPrompt": None,
        }

        # Retrieve conversation history for the user
        conversation = await self.get_conversation(user_id)
        payload["messages"] = conversation + payload["messages"]

        headers = {
            "Content-Type": Content_Type.decode("utf-16"),
            "Cookie": Cookie.decode("utf-16"),
            "Origin": Origin.decode("utf-16"),
            "User-Agent": User_Agent.decode("utf-16"),
        }

        try:
            response = await AsyicXSearcher.search(
                url, post=True, headers=headers, json=payload
            )
            if response:
                clean_text = response.replace("$@$v=undefined-rv1$@$", "")
                pattern = m("ciJcJEBcJHY9djFcLlxkezJ9LXJ2MVwkQFwkIg==").decode("utf-8")
                clean_text = re.sub(pattern, "", clean_text)
                split_text = clean_text.split("\n\n", 2)

                if len(split_text) >= 3:
                    response_content = split_text[2].strip()
                else:
                    response_content = clean_text

                # Update conversation history
                new_conversation = payload["messages"] + [
                    {
                        "id": "XM7KpOE",
                        "content": response_content,
                        "role": "assistant",
                    }
                ]
                await self.save_conversation(user_id, new_conversation)
                return {"answer": response_content, "success": True}
            else:
                return {"answer": "No Response", "success": False}

        except Exception as e:
            return {"results": str(e), "success": False}



from typing import List, Optional


class AgentInfo:
    def __init__(
        self,
        name: str,
        version: str,
        device: Optional[str] = None,
        os_name: Optional[str] = None,
        arch_type: Optional[str] = None,
    ):
        self.name: str = name
        self.version: str = version
        self.device: Optional[str] = device
        self.os_name: Optional[str] = os_name
        self.arch_type: Optional[str] = arch_type


class UserAgent:
    def __init__(
        self,
        user_agents: List[AgentInfo],
    ):
        self.user_agents: List[AgentInfo] = user_agents

    def __str__(self):
        return " ".join(
            [
                f"{user_agent.name}/{user_agent.version}"
                " ("
                + "; ".join(
                    filter(
                        bool,
                        [
                            user_agent.device,
                            user_agent.os_name,
                            user_agent.arch_type,
                        ],
                    ),
                )
                + ");"
                for user_agent in self.user_agents
            ]
        ).replace(" ()", "")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from pyrogram import Client, filters
from pyrogram.types import Message


class TelegramUserInfo:
    def __init__(self, info_id):
        self.info_id = info_id

    async def who_is(self, client: Client):
        try:
            user = await client.get_users(self.info_id)
            username = f"@{user.username}" if user.username else "-"
            first_name = f"{user.first_name}" if user.first_name else "-"
            last_name = f"{user.last_name}" if user.last_name else "-"
            fullname = f"{user.first_name} {user.last_name}" if user.last_name else user.first_name
            user_details = (await client.get_chat(user.id)).bio
            bio = f"{user_details}" if user_details else "-"
            h = f"{user.status}"
            if h.startswith("UserStatus"):
                y = h.replace("UserStatus.", "")
                status = y.capitalize()
            else:
                status = "-"
            dc_id = f"{user.dc_id}" if user.dc_id else "-"
            common = await client.get_common_chats(user.id)
            out_str = f"""<b>USER INFORMATION:</b>
🆔 <b>User ID:</b> <code>{user.id}</code>
👤 <b>First Name:</b> {first_name}
🗣️ <b>Last Name:</b> {last_name}
🌐 <b>Username:</b> {username}
🏛️ <b>DC ID:</b> <code>{dc_id}</code>
🤖 <b>Is Bot:</b> <code>{user.is_bot}</code>
🚷 <b>Is Scam:</b> <code>{user.is_scam}</code>
🚫 <b>Restricted:</b> <code>{user.is_restricted}</code>
✅ <b>Verified:</b> <code>{user.is_verified}</code>
⭐ <b>Premium:</b> <code>{user.is_premium}</code>
📝 <b>User Bio:</b> {bio}

👀 <b>Same groups seen:</b> {len(common)}
👁️ <b>Last Seen:</b> <code>{status}</code>
🔗 <b>User permanent link:</b> <a href='tg://user?id={user.id}'>{fullname}</a>
"""
            photo_id = user.photo.big_file_id if user.photo else None
            if photo_id:
                photo = await client.download_media(photo_id)
                return [photo, out_str]
            else:
                return out_str
        except Exception as e:
            return f"INFO: {e}"
